package com.jiuqi.util.tree;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/* loaded from: com_jiuqi_util_tree.jar:com/jiuqi/util/tree/TreeNode.class */
public class TreeNode {
    private Object item;
    private TreeNode parent;
    private List children;
    private Object tag;

    public TreeNode() {
        this.children = new ArrayList();
    }

    public TreeNode(Object item) {
        this();
        this.item = item;
    }

    public Object getItem() {
        return this.item;
    }

    public void setItem(Object item) {
        this.item = item;
    }

    public TreeNode getParent() {
        return this.parent;
    }

    public void setParent(TreeNode parent) {
        if (this.parent != null) {
            this.parent.children.remove(this);
        }
        this.parent = parent;
        if (parent != null) {
            parent.children.add(this);
        }
    }

    public int size() {
        return this.children.size();
    }

    public TreeNode get(int index) {
        return (TreeNode) this.children.get(index);
    }

    public void add(int index, TreeNode node) {
        node.setParent(null);
        this.children.add(index, node);
        node.parent = this;
    }

    public void remove(int index) {
        remove(get(index));
    }

    public void remove(TreeNode node) {
        node.setParent(null);
    }

    public TreeNode[] getChildren() {
        return (TreeNode[]) this.children.toArray(new TreeNode[0]);
    }

    public int level() {
        int level = 0;
        TreeNode parent = getParent();
        while (true) {
            TreeNode p = parent;
            if (p != null) {
                level++;
                parent = p.getParent();
            } else {
                return level;
            }
        }
    }

    public Object getTag() {
        return this.tag;
    }

    public void setTag(Object tag) {
        this.tag = tag;
    }

    public Iterator iterator() {
        return new TreeIterator(this);
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer("[Level: ");
        buffer.append(level());
        buffer.append("; Node: ");
        buffer.append(this.item == null ? "<null>" : this.item.toString());
        buffer.append(", Children: ");
        buffer.append(size());
        buffer.append(']');
        return buffer.toString();
    }
}
